<a id="mypy-boto3-lightsail"></a>

# mypy-boto3-lightsail

[![PyPI - mypy-boto3-lightsail](https://img.shields.io/pypi/v/mypy-boto3-lightsail.svg?color=blue)](https://pypi.org/project/mypy-boto3-lightsail)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-lightsail.svg?color=blue)](https://pypi.org/project/mypy-boto3-lightsail)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-lightsail?color=blue)](https://pypistats.org/packages/mypy-boto3-lightsail)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Lightsail 1.18.11](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/lightsail.html#Lightsail)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-lightsail docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lightsail/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-lightsail](#mypy-boto3-lightsail)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Lightsail` service.

```bash
python -m pip install boto3-stubs[lightsail]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[lightsail]` in your environment:
  `python -m pip install 'boto3-stubs[lightsail]'`

Both type checking and auto-complete should work for `Lightsail` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[lightsail]` in your environment:
  `python -m pip install 'boto3-stubs[lightsail]'`

Both type checking and auto-complete should work for `Lightsail` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[lightsail]` in your environment:
  `python -m pip install 'boto3-stubs[lightsail]'`
- Run `mypy` as usual

Type checking should work for `Lightsail` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[lightsail]` in your environment:
  `python -m pip install 'boto3-stubs[lightsail]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Lightsail` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`LightsailClient` provides annotations for `boto3.client("lightsail")`.

```python
import boto3

from mypy_boto3_lightsail import LightsailClient

client: LightsailClient = boto3.client("lightsail")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: LightsailClient = session.client("lightsail")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_lightsail.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_lightsail import LightsailClient
from mypy_boto3_lightsail.paginator import (
    GetActiveNamesPaginator,
    GetBlueprintsPaginator,
    GetBundlesPaginator,
    GetCloudFormationStackRecordsPaginator,
    GetDiskSnapshotsPaginator,
    GetDisksPaginator,
    GetDomainsPaginator,
    GetExportSnapshotRecordsPaginator,
    GetInstanceSnapshotsPaginator,
    GetInstancesPaginator,
    GetKeyPairsPaginator,
    GetLoadBalancersPaginator,
    GetOperationsPaginator,
    GetRelationalDatabaseBlueprintsPaginator,
    GetRelationalDatabaseBundlesPaginator,
    GetRelationalDatabaseEventsPaginator,
    GetRelationalDatabaseParametersPaginator,
    GetRelationalDatabaseSnapshotsPaginator,
    GetRelationalDatabasesPaginator,
    GetStaticIpsPaginator,
)

client: LightsailClient = boto3.client("lightsail")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_active_names_paginator: GetActiveNamesPaginator = client.get_paginator("get_active_names")
get_blueprints_paginator: GetBlueprintsPaginator = client.get_paginator("get_blueprints")
get_bundles_paginator: GetBundlesPaginator = client.get_paginator("get_bundles")
get_cloud_formation_stack_records_paginator: GetCloudFormationStackRecordsPaginator = client.get_paginator("get_cloud_formation_stack_records")
get_disk_snapshots_paginator: GetDiskSnapshotsPaginator = client.get_paginator("get_disk_snapshots")
get_disks_paginator: GetDisksPaginator = client.get_paginator("get_disks")
get_domains_paginator: GetDomainsPaginator = client.get_paginator("get_domains")
get_export_snapshot_records_paginator: GetExportSnapshotRecordsPaginator = client.get_paginator("get_export_snapshot_records")
get_instance_snapshots_paginator: GetInstanceSnapshotsPaginator = client.get_paginator("get_instance_snapshots")
get_instances_paginator: GetInstancesPaginator = client.get_paginator("get_instances")
get_key_pairs_paginator: GetKeyPairsPaginator = client.get_paginator("get_key_pairs")
get_load_balancers_paginator: GetLoadBalancersPaginator = client.get_paginator("get_load_balancers")
get_operations_paginator: GetOperationsPaginator = client.get_paginator("get_operations")
get_relational_database_blueprints_paginator: GetRelationalDatabaseBlueprintsPaginator = client.get_paginator("get_relational_database_blueprints")
get_relational_database_bundles_paginator: GetRelationalDatabaseBundlesPaginator = client.get_paginator("get_relational_database_bundles")
get_relational_database_events_paginator: GetRelationalDatabaseEventsPaginator = client.get_paginator("get_relational_database_events")
get_relational_database_parameters_paginator: GetRelationalDatabaseParametersPaginator = client.get_paginator("get_relational_database_parameters")
get_relational_database_snapshots_paginator: GetRelationalDatabaseSnapshotsPaginator = client.get_paginator("get_relational_database_snapshots")
get_relational_databases_paginator: GetRelationalDatabasesPaginator = client.get_paginator("get_relational_databases")
get_static_ips_paginator: GetStaticIpsPaginator = client.get_paginator("get_static_ips")
```

<a id="literals"></a>

### Literals

`mypy_boto3_lightsail.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_lightsail.literals import (
    AccessDirectionType,
    AccessTypeType,
    AddOnTypeType,
    AlarmStateType,
    AutoSnapshotStatusType,
    BehaviorEnumType,
    BlueprintTypeType,
    BucketMetricNameType,
    CertificateStatusType,
    CloudFormationStackRecordSourceTypeType,
    ComparisonOperatorType,
    ContactMethodStatusType,
    ContactMethodVerificationProtocolType,
    ContactProtocolType,
    ContainerServiceDeploymentStateType,
    ContainerServiceMetricNameType,
    ContainerServicePowerNameType,
    ContainerServiceProtocolType,
    ContainerServiceStateDetailCodeType,
    ContainerServiceStateType,
    DiskSnapshotStateType,
    DiskStateType,
    DistributionMetricNameType,
    ExportSnapshotRecordSourceTypeType,
    ForwardValuesType,
    GetActiveNamesPaginatorName,
    GetBlueprintsPaginatorName,
    GetBundlesPaginatorName,
    GetCloudFormationStackRecordsPaginatorName,
    GetDiskSnapshotsPaginatorName,
    GetDisksPaginatorName,
    GetDomainsPaginatorName,
    GetExportSnapshotRecordsPaginatorName,
    GetInstanceSnapshotsPaginatorName,
    GetInstancesPaginatorName,
    GetKeyPairsPaginatorName,
    GetLoadBalancersPaginatorName,
    GetOperationsPaginatorName,
    GetRelationalDatabaseBlueprintsPaginatorName,
    GetRelationalDatabaseBundlesPaginatorName,
    GetRelationalDatabaseEventsPaginatorName,
    GetRelationalDatabaseParametersPaginatorName,
    GetRelationalDatabaseSnapshotsPaginatorName,
    GetRelationalDatabasesPaginatorName,
    GetStaticIpsPaginatorName,
    HeaderEnumType,
    InstanceAccessProtocolType,
    InstanceHealthReasonType,
    InstanceHealthStateType,
    InstanceMetricNameType,
    InstancePlatformType,
    InstanceSnapshotStateType,
    IpAddressTypeType,
    LoadBalancerAttributeNameType,
    LoadBalancerMetricNameType,
    LoadBalancerProtocolType,
    LoadBalancerStateType,
    LoadBalancerTlsCertificateDomainStatusType,
    LoadBalancerTlsCertificateFailureReasonType,
    LoadBalancerTlsCertificateRenewalStatusType,
    LoadBalancerTlsCertificateRevocationReasonType,
    LoadBalancerTlsCertificateStatusType,
    MetricNameType,
    MetricStatisticType,
    MetricUnitType,
    NetworkProtocolType,
    OperationStatusType,
    OperationTypeType,
    OriginProtocolPolicyEnumType,
    PortAccessTypeType,
    PortInfoSourceTypeType,
    PortStateType,
    RecordStateType,
    RegionNameType,
    RelationalDatabaseEngineType,
    RelationalDatabaseMetricNameType,
    RelationalDatabasePasswordVersionType,
    RenewalStatusType,
    ResourceBucketAccessType,
    ResourceTypeType,
    StatusTypeType,
    TreatMissingDataType,
)

def check_value(value: AccessDirectionType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_lightsail.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_lightsail.type_defs import (
    AccessKeyTypeDef,
    AccessRulesTypeDef,
    AddOnRequestTypeDef,
    AddOnTypeDef,
    AlarmTypeDef,
    AllocateStaticIpRequestRequestTypeDef,
    AllocateStaticIpResultTypeDef,
    AttachCertificateToDistributionRequestRequestTypeDef,
    AttachCertificateToDistributionResultTypeDef,
    AttachDiskRequestRequestTypeDef,
    AttachDiskResultTypeDef,
    AttachInstancesToLoadBalancerRequestRequestTypeDef,
    AttachInstancesToLoadBalancerResultTypeDef,
    AttachLoadBalancerTlsCertificateRequestRequestTypeDef,
    AttachLoadBalancerTlsCertificateResultTypeDef,
    AttachStaticIpRequestRequestTypeDef,
    AttachStaticIpResultTypeDef,
    AttachedDiskTypeDef,
    AutoSnapshotAddOnRequestTypeDef,
    AutoSnapshotDetailsTypeDef,
    AvailabilityZoneTypeDef,
    BlueprintTypeDef,
    BucketBundleTypeDef,
    BucketStateTypeDef,
    BucketTypeDef,
    BundleTypeDef,
    CacheBehaviorPerPathTypeDef,
    CacheBehaviorTypeDef,
    CacheSettingsTypeDef,
    CertificateSummaryTypeDef,
    CertificateTypeDef,
    CloseInstancePublicPortsRequestRequestTypeDef,
    CloseInstancePublicPortsResultTypeDef,
    CloudFormationStackRecordSourceInfoTypeDef,
    CloudFormationStackRecordTypeDef,
    ContactMethodTypeDef,
    ContainerImageTypeDef,
    ContainerServiceDeploymentRequestTypeDef,
    ContainerServiceDeploymentTypeDef,
    ContainerServiceEndpointTypeDef,
    ContainerServiceHealthCheckConfigTypeDef,
    ContainerServiceLogEventTypeDef,
    ContainerServicePowerTypeDef,
    ContainerServiceRegistryLoginTypeDef,
    ContainerServiceStateDetailTypeDef,
    ContainerServiceTypeDef,
    ContainerServicesListResultTypeDef,
    ContainerTypeDef,
    CookieObjectTypeDef,
    CopySnapshotRequestRequestTypeDef,
    CopySnapshotResultTypeDef,
    CreateBucketAccessKeyRequestRequestTypeDef,
    CreateBucketAccessKeyResultTypeDef,
    CreateBucketRequestRequestTypeDef,
    CreateBucketResultTypeDef,
    CreateCertificateRequestRequestTypeDef,
    CreateCertificateResultTypeDef,
    CreateCloudFormationStackRequestRequestTypeDef,
    CreateCloudFormationStackResultTypeDef,
    CreateContactMethodRequestRequestTypeDef,
    CreateContactMethodResultTypeDef,
    CreateContainerServiceDeploymentRequestRequestTypeDef,
    CreateContainerServiceDeploymentResultTypeDef,
    CreateContainerServiceRegistryLoginResultTypeDef,
    CreateContainerServiceRequestRequestTypeDef,
    CreateContainerServiceResultTypeDef,
    CreateDiskFromSnapshotRequestRequestTypeDef,
    CreateDiskFromSnapshotResultTypeDef,
    CreateDiskRequestRequestTypeDef,
    CreateDiskResultTypeDef,
    CreateDiskSnapshotRequestRequestTypeDef,
    CreateDiskSnapshotResultTypeDef,
    CreateDistributionRequestRequestTypeDef,
    CreateDistributionResultTypeDef,
    CreateDomainEntryRequestRequestTypeDef,
    CreateDomainEntryResultTypeDef,
    CreateDomainRequestRequestTypeDef,
    CreateDomainResultTypeDef,
    CreateInstanceSnapshotRequestRequestTypeDef,
    CreateInstanceSnapshotResultTypeDef,
    CreateInstancesFromSnapshotRequestRequestTypeDef,
    CreateInstancesFromSnapshotResultTypeDef,
    CreateInstancesRequestRequestTypeDef,
    CreateInstancesResultTypeDef,
    CreateKeyPairRequestRequestTypeDef,
    CreateKeyPairResultTypeDef,
    CreateLoadBalancerRequestRequestTypeDef,
    CreateLoadBalancerResultTypeDef,
    CreateLoadBalancerTlsCertificateRequestRequestTypeDef,
    CreateLoadBalancerTlsCertificateResultTypeDef,
    CreateRelationalDatabaseFromSnapshotRequestRequestTypeDef,
    CreateRelationalDatabaseFromSnapshotResultTypeDef,
    CreateRelationalDatabaseRequestRequestTypeDef,
    CreateRelationalDatabaseResultTypeDef,
    CreateRelationalDatabaseSnapshotRequestRequestTypeDef,
    CreateRelationalDatabaseSnapshotResultTypeDef,
    DeleteAlarmRequestRequestTypeDef,
    DeleteAlarmResultTypeDef,
    DeleteAutoSnapshotRequestRequestTypeDef,
    DeleteAutoSnapshotResultTypeDef,
    DeleteBucketAccessKeyRequestRequestTypeDef,
    DeleteBucketAccessKeyResultTypeDef,
    DeleteBucketRequestRequestTypeDef,
    DeleteBucketResultTypeDef,
    DeleteCertificateRequestRequestTypeDef,
    DeleteCertificateResultTypeDef,
    DeleteContactMethodRequestRequestTypeDef,
    DeleteContactMethodResultTypeDef,
    DeleteContainerImageRequestRequestTypeDef,
    DeleteContainerServiceRequestRequestTypeDef,
    DeleteDiskRequestRequestTypeDef,
    DeleteDiskResultTypeDef,
    DeleteDiskSnapshotRequestRequestTypeDef,
    DeleteDiskSnapshotResultTypeDef,
    DeleteDistributionRequestRequestTypeDef,
    DeleteDistributionResultTypeDef,
    DeleteDomainEntryRequestRequestTypeDef,
    DeleteDomainEntryResultTypeDef,
    DeleteDomainRequestRequestTypeDef,
    DeleteDomainResultTypeDef,
    DeleteInstanceRequestRequestTypeDef,
    DeleteInstanceResultTypeDef,
    DeleteInstanceSnapshotRequestRequestTypeDef,
    DeleteInstanceSnapshotResultTypeDef,
    DeleteKeyPairRequestRequestTypeDef,
    DeleteKeyPairResultTypeDef,
    DeleteKnownHostKeysRequestRequestTypeDef,
    DeleteKnownHostKeysResultTypeDef,
    DeleteLoadBalancerRequestRequestTypeDef,
    DeleteLoadBalancerResultTypeDef,
    DeleteLoadBalancerTlsCertificateRequestRequestTypeDef,
    DeleteLoadBalancerTlsCertificateResultTypeDef,
    DeleteRelationalDatabaseRequestRequestTypeDef,
    DeleteRelationalDatabaseResultTypeDef,
    DeleteRelationalDatabaseSnapshotRequestRequestTypeDef,
    DeleteRelationalDatabaseSnapshotResultTypeDef,
    DestinationInfoTypeDef,
    DetachCertificateFromDistributionRequestRequestTypeDef,
    DetachCertificateFromDistributionResultTypeDef,
    DetachDiskRequestRequestTypeDef,
    DetachDiskResultTypeDef,
    DetachInstancesFromLoadBalancerRequestRequestTypeDef,
    DetachInstancesFromLoadBalancerResultTypeDef,
    DetachStaticIpRequestRequestTypeDef,
    DetachStaticIpResultTypeDef,
    DisableAddOnRequestRequestTypeDef,
    DisableAddOnResultTypeDef,
    DiskInfoTypeDef,
    DiskMapTypeDef,
    DiskSnapshotInfoTypeDef,
    DiskSnapshotTypeDef,
    DiskTypeDef,
    DistributionBundleTypeDef,
    DomainEntryTypeDef,
    DomainTypeDef,
    DomainValidationRecordTypeDef,
    DownloadDefaultKeyPairResultTypeDef,
    EnableAddOnRequestRequestTypeDef,
    EnableAddOnResultTypeDef,
    EndpointRequestTypeDef,
    ExportSnapshotRecordSourceInfoTypeDef,
    ExportSnapshotRecordTypeDef,
    ExportSnapshotRequestRequestTypeDef,
    ExportSnapshotResultTypeDef,
    GetActiveNamesRequestRequestTypeDef,
    GetActiveNamesResultTypeDef,
    GetAlarmsRequestRequestTypeDef,
    GetAlarmsResultTypeDef,
    GetAutoSnapshotsRequestRequestTypeDef,
    GetAutoSnapshotsResultTypeDef,
    GetBlueprintsRequestRequestTypeDef,
    GetBlueprintsResultTypeDef,
    GetBucketAccessKeysRequestRequestTypeDef,
    GetBucketAccessKeysResultTypeDef,
    GetBucketBundlesRequestRequestTypeDef,
    GetBucketBundlesResultTypeDef,
    GetBucketMetricDataRequestRequestTypeDef,
    GetBucketMetricDataResultTypeDef,
    GetBucketsRequestRequestTypeDef,
    GetBucketsResultTypeDef,
    GetBundlesRequestRequestTypeDef,
    GetBundlesResultTypeDef,
    GetCertificatesRequestRequestTypeDef,
    GetCertificatesResultTypeDef,
    GetCloudFormationStackRecordsRequestRequestTypeDef,
    GetCloudFormationStackRecordsResultTypeDef,
    GetContactMethodsRequestRequestTypeDef,
    GetContactMethodsResultTypeDef,
    GetContainerAPIMetadataResultTypeDef,
    GetContainerImagesRequestRequestTypeDef,
    GetContainerImagesResultTypeDef,
    GetContainerLogRequestRequestTypeDef,
    GetContainerLogResultTypeDef,
    GetContainerServiceDeploymentsRequestRequestTypeDef,
    GetContainerServiceDeploymentsResultTypeDef,
    GetContainerServiceMetricDataRequestRequestTypeDef,
    GetContainerServiceMetricDataResultTypeDef,
    GetContainerServicePowersResultTypeDef,
    GetContainerServicesRequestRequestTypeDef,
    GetDiskRequestRequestTypeDef,
    GetDiskResultTypeDef,
    GetDiskSnapshotRequestRequestTypeDef,
    GetDiskSnapshotResultTypeDef,
    GetDiskSnapshotsRequestRequestTypeDef,
    GetDiskSnapshotsResultTypeDef,
    GetDisksRequestRequestTypeDef,
    GetDisksResultTypeDef,
    GetDistributionBundlesResultTypeDef,
    GetDistributionLatestCacheResetRequestRequestTypeDef,
    GetDistributionLatestCacheResetResultTypeDef,
    GetDistributionMetricDataRequestRequestTypeDef,
    GetDistributionMetricDataResultTypeDef,
    GetDistributionsRequestRequestTypeDef,
    GetDistributionsResultTypeDef,
    GetDomainRequestRequestTypeDef,
    GetDomainResultTypeDef,
    GetDomainsRequestRequestTypeDef,
    GetDomainsResultTypeDef,
    GetExportSnapshotRecordsRequestRequestTypeDef,
    GetExportSnapshotRecordsResultTypeDef,
    GetInstanceAccessDetailsRequestRequestTypeDef,
    GetInstanceAccessDetailsResultTypeDef,
    GetInstanceMetricDataRequestRequestTypeDef,
    GetInstanceMetricDataResultTypeDef,
    GetInstancePortStatesRequestRequestTypeDef,
    GetInstancePortStatesResultTypeDef,
    GetInstanceRequestRequestTypeDef,
    GetInstanceResultTypeDef,
    GetInstanceSnapshotRequestRequestTypeDef,
    GetInstanceSnapshotResultTypeDef,
    GetInstanceSnapshotsRequestRequestTypeDef,
    GetInstanceSnapshotsResultTypeDef,
    GetInstanceStateRequestRequestTypeDef,
    GetInstanceStateResultTypeDef,
    GetInstancesRequestRequestTypeDef,
    GetInstancesResultTypeDef,
    GetKeyPairRequestRequestTypeDef,
    GetKeyPairResultTypeDef,
    GetKeyPairsRequestRequestTypeDef,
    GetKeyPairsResultTypeDef,
    GetLoadBalancerMetricDataRequestRequestTypeDef,
    GetLoadBalancerMetricDataResultTypeDef,
    GetLoadBalancerRequestRequestTypeDef,
    GetLoadBalancerResultTypeDef,
    GetLoadBalancerTlsCertificatesRequestRequestTypeDef,
    GetLoadBalancerTlsCertificatesResultTypeDef,
    GetLoadBalancersRequestRequestTypeDef,
    GetLoadBalancersResultTypeDef,
    GetOperationRequestRequestTypeDef,
    GetOperationResultTypeDef,
    GetOperationsForResourceRequestRequestTypeDef,
    GetOperationsForResourceResultTypeDef,
    GetOperationsRequestRequestTypeDef,
    GetOperationsResultTypeDef,
    GetRegionsRequestRequestTypeDef,
    GetRegionsResultTypeDef,
    GetRelationalDatabaseBlueprintsRequestRequestTypeDef,
    GetRelationalDatabaseBlueprintsResultTypeDef,
    GetRelationalDatabaseBundlesRequestRequestTypeDef,
    GetRelationalDatabaseBundlesResultTypeDef,
    GetRelationalDatabaseEventsRequestRequestTypeDef,
    GetRelationalDatabaseEventsResultTypeDef,
    GetRelationalDatabaseLogEventsRequestRequestTypeDef,
    GetRelationalDatabaseLogEventsResultTypeDef,
    GetRelationalDatabaseLogStreamsRequestRequestTypeDef,
    GetRelationalDatabaseLogStreamsResultTypeDef,
    GetRelationalDatabaseMasterUserPasswordRequestRequestTypeDef,
    GetRelationalDatabaseMasterUserPasswordResultTypeDef,
    GetRelationalDatabaseMetricDataRequestRequestTypeDef,
    GetRelationalDatabaseMetricDataResultTypeDef,
    GetRelationalDatabaseParametersRequestRequestTypeDef,
    GetRelationalDatabaseParametersResultTypeDef,
    GetRelationalDatabaseRequestRequestTypeDef,
    GetRelationalDatabaseResultTypeDef,
    GetRelationalDatabaseSnapshotRequestRequestTypeDef,
    GetRelationalDatabaseSnapshotResultTypeDef,
    GetRelationalDatabaseSnapshotsRequestRequestTypeDef,
    GetRelationalDatabaseSnapshotsResultTypeDef,
    GetRelationalDatabasesRequestRequestTypeDef,
    GetRelationalDatabasesResultTypeDef,
    GetStaticIpRequestRequestTypeDef,
    GetStaticIpResultTypeDef,
    GetStaticIpsRequestRequestTypeDef,
    GetStaticIpsResultTypeDef,
    HeaderObjectTypeDef,
    HostKeyAttributesTypeDef,
    ImportKeyPairRequestRequestTypeDef,
    ImportKeyPairResultTypeDef,
    InputOriginTypeDef,
    InstanceAccessDetailsTypeDef,
    InstanceEntryTypeDef,
    InstanceHardwareTypeDef,
    InstanceHealthSummaryTypeDef,
    InstanceNetworkingTypeDef,
    InstancePortInfoTypeDef,
    InstancePortStateTypeDef,
    InstanceSnapshotInfoTypeDef,
    InstanceSnapshotTypeDef,
    InstanceStateTypeDef,
    InstanceTypeDef,
    IsVpcPeeredResultTypeDef,
    KeyPairTypeDef,
    LightsailDistributionTypeDef,
    LoadBalancerTlsCertificateDomainValidationOptionTypeDef,
    LoadBalancerTlsCertificateDomainValidationRecordTypeDef,
    LoadBalancerTlsCertificateRenewalSummaryTypeDef,
    LoadBalancerTlsCertificateSummaryTypeDef,
    LoadBalancerTlsCertificateTypeDef,
    LoadBalancerTypeDef,
    LogEventTypeDef,
    MetricDatapointTypeDef,
    MonitoredResourceInfoTypeDef,
    MonthlyTransferTypeDef,
    OpenInstancePublicPortsRequestRequestTypeDef,
    OpenInstancePublicPortsResultTypeDef,
    OperationTypeDef,
    OriginTypeDef,
    PaginatorConfigTypeDef,
    PasswordDataTypeDef,
    PeerVpcResultTypeDef,
    PendingMaintenanceActionTypeDef,
    PendingModifiedRelationalDatabaseValuesTypeDef,
    PortInfoTypeDef,
    PutAlarmRequestRequestTypeDef,
    PutAlarmResultTypeDef,
    PutInstancePublicPortsRequestRequestTypeDef,
    PutInstancePublicPortsResultTypeDef,
    QueryStringObjectTypeDef,
    RebootInstanceRequestRequestTypeDef,
    RebootInstanceResultTypeDef,
    RebootRelationalDatabaseRequestRequestTypeDef,
    RebootRelationalDatabaseResultTypeDef,
    RegionTypeDef,
    RegisterContainerImageRequestRequestTypeDef,
    RegisterContainerImageResultTypeDef,
    RelationalDatabaseBlueprintTypeDef,
    RelationalDatabaseBundleTypeDef,
    RelationalDatabaseEndpointTypeDef,
    RelationalDatabaseEventTypeDef,
    RelationalDatabaseHardwareTypeDef,
    RelationalDatabaseParameterTypeDef,
    RelationalDatabaseSnapshotTypeDef,
    RelationalDatabaseTypeDef,
    ReleaseStaticIpRequestRequestTypeDef,
    ReleaseStaticIpResultTypeDef,
    RenewalSummaryTypeDef,
    ResetDistributionCacheRequestRequestTypeDef,
    ResetDistributionCacheResultTypeDef,
    ResourceLocationTypeDef,
    ResourceReceivingAccessTypeDef,
    ResourceRecordTypeDef,
    ResponseMetadataTypeDef,
    SendContactMethodVerificationRequestRequestTypeDef,
    SendContactMethodVerificationResultTypeDef,
    SetIpAddressTypeRequestRequestTypeDef,
    SetIpAddressTypeResultTypeDef,
    SetResourceAccessForBucketRequestRequestTypeDef,
    SetResourceAccessForBucketResultTypeDef,
    StartInstanceRequestRequestTypeDef,
    StartInstanceResultTypeDef,
    StartRelationalDatabaseRequestRequestTypeDef,
    StartRelationalDatabaseResultTypeDef,
    StaticIpTypeDef,
    StopInstanceRequestRequestTypeDef,
    StopInstanceResultTypeDef,
    StopRelationalDatabaseRequestRequestTypeDef,
    StopRelationalDatabaseResultTypeDef,
    TagResourceRequestRequestTypeDef,
    TagResourceResultTypeDef,
    TagTypeDef,
    TestAlarmRequestRequestTypeDef,
    TestAlarmResultTypeDef,
    UnpeerVpcResultTypeDef,
    UntagResourceRequestRequestTypeDef,
    UntagResourceResultTypeDef,
    UpdateBucketBundleRequestRequestTypeDef,
    UpdateBucketBundleResultTypeDef,
    UpdateBucketRequestRequestTypeDef,
    UpdateBucketResultTypeDef,
    UpdateContainerServiceRequestRequestTypeDef,
    UpdateContainerServiceResultTypeDef,
    UpdateDistributionBundleRequestRequestTypeDef,
    UpdateDistributionBundleResultTypeDef,
    UpdateDistributionRequestRequestTypeDef,
    UpdateDistributionResultTypeDef,
    UpdateDomainEntryRequestRequestTypeDef,
    UpdateDomainEntryResultTypeDef,
    UpdateLoadBalancerAttributeRequestRequestTypeDef,
    UpdateLoadBalancerAttributeResultTypeDef,
    UpdateRelationalDatabaseParametersRequestRequestTypeDef,
    UpdateRelationalDatabaseParametersResultTypeDef,
    UpdateRelationalDatabaseRequestRequestTypeDef,
    UpdateRelationalDatabaseResultTypeDef,
)

def get_structure() -> AccessKeyTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-lightsail` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-lightsail docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lightsail/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
